pub struct Account { /* private fields */ }Expand description
A Telegram account extracted from tdata
Implementations
Sourceimpl Account
impl Account
Sourcepub fn user_id(&self) -> i64
pub fn user_id(&self) -> i64
Get the Telegram user ID.
Treat account identifiers as private data and avoid logging them.
Sourcepub fn auth_key_bytes(&self) -> &[u8; 256]
pub fn auth_key_bytes(&self) -> &[u8; 256]
Get the raw auth key bytes.
This grants access to the Telegram account. Never log, serialize, or expose it.
Sourcepub fn to_grammers_session_data(&self) -> SessionData
pub fn to_grammers_session_data(&self) -> SessionData
Convert to grammers SessionData.
The returned value contains live authentication credentials and can be imported
into any grammers session storage. Never log or expose it.